@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Combinatorial algorithms to generate rhythms
 
-our $VERSION = '0.0800';
+our $VERSION = '0.0801';
 
 use Moo;
 use strictures 2;
@@ -12,9 +12,13 @@ use Data::Munge qw(list2re);
 use Integer::Partition ();
 use List::Util qw(all any);
 use Math::Sequence::DeBruijn qw(debruijn);
+use Module::Load::Conditional qw(check_install);
 use Music::AtonalUtil ();
 use namespace::clean;
 
+use if defined check_install(module => 'Math::NumSeq::SqrtContinued'),
+    'Math::NumSeq::SqrtContinued';
+
 
 has verbose => (
     is      => 'ro',
@@ -62,10 +66,6 @@ sub cfsqrt {
     my ($self, $n, $m) = @_;
     $m ||= $n;
     my @terms;
-    my $ok = eval "require Math::NumSeq::SqrtContinued; 1";
-    #my $ok = eval { require Math::NumSeq::SqrtContinued; 1 };
-    die 'ERROR: Math::NumSeq::SqrtContinued not installed'
-        unless $ok;
 
     my $seq = Math::NumSeq::SqrtContinued->new(sqrt => $n);
     for my $i (1 .. $m) {
@@ -602,7 +602,7 @@ Music::CreatingRhythms - Combinatorial algorithms to generate rhythms
 
 =head1 VERSION
 
-version 0.0800
+version 0.0801
 
 =head1 SYNOPSIS
 
